//  "KP_Spline.inc" by Dave Matthews, 2005
//Array of a knot to use to fill a spline. The full array goes from 0 .. (Array_Size-1)
//This creates N_Of_Splines parallel splines 

// The below pov file is an array[Arr_Size] named KNOT.  
// It declares the following variable names:
// Arr_Size -- Number of vectors (0..Arr_Size-1)
// N_Of_Splines -- Number of edge splines in the aray (= 'nseg' in KnotPlot)
// KNOT -- an array of size Arr_Size


#ifndef(KNOT)
#include "KP_Array.pov"
#end


/////////////////////////////////////////////////////////////  
//// Here are the splines
//// The edge splines are stored in an array called
//// KNOT_Spline[], referenced 0 .. N_Of_Splines - 1
//// The center spline is created and called KNOT_SplineC                                
/////////////////////////////////////////////////////////////

#macro K_Spline(Arr_Start,Arr_Stop)  

#local Spline_Size = Arr_Stop - Arr_Start + 1;   

spline { natural_spline 
   #local J = 0;
   //-1/(Spline_Size), KNOT[Arr_Stop]   //Control point for cubic_spline
   #while (J < Spline_Size)
   J/(Spline_Size), KNOT[J+Arr_Start]
   #local J = J + 1;
   #end
   1, KNOT[Arr_Start]        //Close the loop
   //1+ 1/Spline_Size, KNOT[Arr_Start+1]        //Control point for cubic_spline
   }  
#end

#declare KNOT_Spline = array [N_Of_Splines];

#declare Count = 0;
#while (Count < N_Of_Splines)
#declare KNOT_Spline[Count] = K_Spline(Count*Arr_Size/N_Of_Splines, (Count+1)*Arr_Size/N_Of_Splines - 1);           
#declare Count = Count + 1;
#end
  

//Averaging the splines, to get a center spline 
//(since the points are vertices of an equilateral triangle) 

#declare KNOT_SplineC = spline { natural_spline
#local S_S = Arr_Size/N_Of_Splines;

#local J = 0;
#while (J < S_S + 1) 
#local Sum = 0;
#local K = 0;
#while (K < N_Of_Splines)
#local Sum = Sum + KNOT_Spline[K](J/S_S);
#local K = K + 1;
#end
   J/S_S, Sum/N_Of_Splines
#local J = J + 1;
#end
    } ;